# Inline Example

Generates an inline example for your end users.  

**Example Usage**  
To see an example of how to use Inline Example, run the following in a python script:  

```
from inline_example.template import example_usage
example_usage()
```